# Copyright 2024 BDP Ecosystem Limited. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from __future__ import annotations

import importlib.util

from ._base import Quantity, fail_for_dimension_mismatch, UNITLESS

matplotlib_installed = importlib.util.find_spec('matplotlib') is not None

if matplotlib_installed:
    from matplotlib import units


    class QuantityConverter(units.ConversionInterface):

        @staticmethod
        def axisinfo(unit, axis):
            if unit == UNITLESS:
                return units.AxisInfo()
            elif unit is not None:
                return units.AxisInfo(label=unit.dispname)
            return None

        @staticmethod
        def convert(val, unit, axis):
            val = Quantity(val)
            # check dimension
            fail_for_dimension_mismatch(val.unit, unit)
            # check unit
            return val.to(unit).mantissa

        @staticmethod
        def default_units(x, axis):
            return x.unit


    units.registry[Quantity] = QuantityConverter()
